GUI and Event Driven Programming
::::::::::::::::::::::::::::::::

.. toctree::
   :caption: GUI Programming
   :maxdepth: 1

   01_intro_gui.rst
   02_standard_dialog_boxes.rst
   03_widgets.rst
   04_layout_managers.rst
   05_widget_grouping.rst
   06_command_events.rst
   07_event_binding.rst
   08_gui_program_structure.rst
   09_modifying_widgets.rst
   10_timer_events.rst
   11_gui_program_example.rst
   12_model_view_controller.rst
   Exercises.rst
   Glossary.rst
